@@ -7,4 +7,7 @@ class URL(object):
     ACCOUNT_LINK = "/v1/qr/sessions"
     PENDING_PAYMENT = "/v1/requestOrder"
     USER_AUTH = "/v2/user/authorizations"
+    GIVE_CASHBACK = "/v2/cashback"
+    REVERSAL_CASHBACK = "/v2/cashback_reversal"
     REFUNDS = "/v2/refunds"
+    
